pub struct StructPlan {
pub reader_type: u16,
pub writer_type: u16,
pub writer_packed: bool,
pub fields: Vec<FieldPlan>,
}Fields
reader_type: u16Index of the corresponding struct in the reader schema.
writer_type: u16Index of the corresponding struct in the writer schema.
writer_packed: boolWhether the writer struct uses the packed layout (offsets are dynamic).
fields: Vec<FieldPlan>Parallel to the reader struct’s ID-sorted fields.